==> blanco.plugin.charactergroup_0.1.6-eclipse3.0.zip: src/blanco/plugin/charactergroup/wizards/BlancoCharacterGroupWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.charactergroup.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.charactergroup.BlancoCharacterGroupConstants;
import blanco.charactergroup.resourcebundle.BlancoCharacterGroupResourceBundle;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoCharacterGroupWizardPage4 extends WizardPage {
    private static final BlancoCharacterGroupResourceBundle fBundle = new BlancoCharacterGroupResourceBundle();

    public BlancoCharacterGroupWizardPage4(ISelection selection) {
        super("wizardPage");
        setTitle(BlancoCharacterGroupConstants.PRODUCT_NAME + "vOCɊ֘AtH_");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText(BlancoCharacterGroupConstants.PRODUCT_NAME
                        + "vOCɊ֘AtH_͉L̂ƂłB");
        new Label(container, SWT.NONE).setText("  1.\[XtH_ (tH_ src 𐄏)");
        new Label(container, SWT.NONE)
                .setText("    \[XtH_ݒ(쐬)邱Ƃ܂B");
        new Label(container, SWT.NONE).setText("  2.^fBNg (tH_ meta"
                + BlancoCharacterGroupConstants.TARGET_SUBDIRECTORY
                + " ܂)");
        new Label(container, SWT.NONE).setText("    "
                + fBundle.getMetafileDisplayname() + "i[܂B");
        new Label(container, SWT.NONE)
                .setText("  3.e|fBNg (tH_ tmp ƂȂ܂)");
        new Label(container, SWT.NONE)
                .setText("  4.\[XR[hfBNg (tH_ blanco/main(Java), blanco.cs/main(C#.NET), blanco.js/main(JavaScript), blanco.php/main(PHP), blanco.ruby/main(Ruby), blanco.python/main(Python) ƂȂ܂)");

        setControl(container);
    }
}

==> blanco.plugin.charactergroup_0.1.8-eclipse3.0.zip: src/blanco/plugin/charactergroup/wizards/BlancoCharacterGroupWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.charactergroup.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.charactergroup.BlancoCharacterGroupConstants;
import blanco.charactergroup.resourcebundle.BlancoCharacterGroupResourceBundle;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoCharacterGroupWizardPage4 extends WizardPage {
    private static final BlancoCharacterGroupResourceBundle fBundle = new BlancoCharacterGroupResourceBundle();

    public BlancoCharacterGroupWizardPage4(ISelection selection) {
        super("wizardPage");
        setTitle(BlancoCharacterGroupConstants.PRODUCT_NAME + "vOCɊ֘AtH_");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText(BlancoCharacterGroupConstants.PRODUCT_NAME
                        + "vOCɊ֘AtH_͉L̂ƂłB");
        new Label(container, SWT.NONE).setText("  1.\[XtH_ (tH_ src 𐄏)");
        new Label(container, SWT.NONE)
                .setText("    \[XtH_ݒ(쐬)邱Ƃ܂B");
        new Label(container, SWT.NONE).setText("  2.^fBNg (tH_ meta"
                + BlancoCharacterGroupConstants.TARGET_SUBDIRECTORY
                + " ܂)");
        new Label(container, SWT.NONE).setText("    "
                + fBundle.getMetafileDisplayname() + "i[܂B");
        new Label(container, SWT.NONE)
                .setText("  3.e|fBNg (tH_ tmp ƂȂ܂)");
        new Label(container, SWT.NONE)
                .setText("  4.\[XR[hfBNg (tH_ blanco/main(Java), blanco.cs/main(C#.NET)");
        new Label(container, SWT.NONE)
                .setText("    , blanco.js/main(JavaScript), blanco.php/main(PHP), blanco.ruby/main(Ruby), blanco.python/main(Python)");
        new Label(container, SWT.NONE).setText("     ƂȂ܂)");

        setControl(container);
    }
}
